==> ejc-settlementmanage-impl-3.0.0-20220420.035439-5-sources.jar: com/ejianc/business/settlementmanage/vo/MaterialPurchaseDetailVO.java <==
package com.ejianc.business.settlementmanage.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 物资采购结算-子表
 * 
 * @author generator
 * 
 */
public class MaterialPurchaseDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long contractId; // 合同id
    private java.lang.String contractName; // 合同名称
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.String sort; // 序号
    private java.lang.String supplyMonth; // 供货月份
    private java.lang.String supplies; // 物资
    private java.lang.String specifications; // 规格型号
    private java.lang.String units; // 单位
    private java.lang.Long quantitySupplied; // 供货数量
    private java.math.BigDecimal extaxContractPrice; // 合同单价(除税)(元)
    private java.math.BigDecimal intaxContractPrice; // 合同单价(含税)(元)
    private java.math.BigDecimal extaxSettlementPrice; // 结算单价(除税)(元)
    private java.math.BigDecimal intaxSettlementPrice; // 结算单价(含税)(元)
    private java.math.BigDecimal extaxSummaryAmount; // 结算金额(除税)(元)
    private java.math.BigDecimal intaxSummaryAmount; // 结算金额(含税)(元)
    private java.lang.String remarks; // 备注
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 供货月份
     */
    public java.lang.String getSupplyMonth() {
        return supplyMonth;
    }

    /**
     * 供货月份
     */
    public void setSupplyMonth(java.lang.String supplyMonth) {
        this.supplyMonth = supplyMonth;
    }
    /**
     * 物资
     */
    public java.lang.String getSupplies() {
        return supplies;
    }

    /**
     * 物资
     */
    public void setSupplies(java.lang.String supplies) {
        this.supplies = supplies;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpecifications() {
        return specifications;
    }

    /**
     * 规格型号
     */
    public void setSpecifications(java.lang.String specifications) {
        this.specifications = specifications;
    }
    /**
     * 单位
     */
    public java.lang.String getUnits() {
        return units;
    }

    /**
     * 单位
     */
    public void setUnits(java.lang.String units) {
        this.units = units;
    }
    /**
     * 供货数量
     */
    public java.lang.Long getQuantitySupplied() {
        return quantitySupplied;
    }

    /**
     * 供货数量
     */
    public void setQuantitySupplied(java.lang.Long quantitySupplied) {
        this.quantitySupplied = quantitySupplied;
    }
    /**
     * 合同单价(除税)(元)
     */
    public java.math.BigDecimal getExtaxContractPrice() {
        return extaxContractPrice;
    }

    /**
     * 合同单价(除税)(元)
     */
    public void setExtaxContractPrice(java.math.BigDecimal extaxContractPrice) {
        this.extaxContractPrice = extaxContractPrice;
    }
    /**
     * 合同单价(含税)(元)
     */
    public java.math.BigDecimal getIntaxContractPrice() {
        return intaxContractPrice;
    }

    /**
     * 合同单价(含税)(元)
     */
    public void setIntaxContractPrice(java.math.BigDecimal intaxContractPrice) {
        this.intaxContractPrice = intaxContractPrice;
    }
    /**
     * 结算单价(除税)(元)
     */
    public java.math.BigDecimal getExtaxSettlementPrice() {
        return extaxSettlementPrice;
    }

    /**
     * 结算单价(除税)(元)
     */
    public void setExtaxSettlementPrice(java.math.BigDecimal extaxSettlementPrice) {
        this.extaxSettlementPrice = extaxSettlementPrice;
    }
    /**
     * 结算单价(含税)(元)
     */
    public java.math.BigDecimal getIntaxSettlementPrice() {
        return intaxSettlementPrice;
    }

    /**
     * 结算单价(含税)(元)
     */
    public void setIntaxSettlementPrice(java.math.BigDecimal intaxSettlementPrice) {
        this.intaxSettlementPrice = intaxSettlementPrice;
    }
    /**
     * 结算金额(除税)(元)
     */
    public java.math.BigDecimal getExtaxSummaryAmount() {
        return extaxSummaryAmount;
    }

    /**
     * 结算金额(除税)(元)
     */
    public void setExtaxSummaryAmount(java.math.BigDecimal extaxSummaryAmount) {
        this.extaxSummaryAmount = extaxSummaryAmount;
    }
    /**
     * 结算金额(含税)(元)
     */
    public java.math.BigDecimal getIntaxSummaryAmount() {
        return intaxSummaryAmount;
    }

    /**
     * 结算金额(含税)(元)
     */
    public void setIntaxSummaryAmount(java.math.BigDecimal intaxSummaryAmount) {
        this.intaxSummaryAmount = intaxSummaryAmount;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    
}

==> ejc-settlementmanage-impl-3.0.0-20230322.091825-186-sources.jar: com/ejianc/business/settlementmanage/vo/MaterialPurchaseDetailVO.java <==
package com.ejianc.business.settlementmanage.vo;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 物资采购结算-子表
 * 
 * @author generator
 * 
 */
public class MaterialPurchaseDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long contractId; // 合同id
    private java.lang.String contractName; // 合同名称
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.String sort; // 序号
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy/MM", timezone = "GMT+8")
    private java.util.Date supplyMonth; // 供货月份
    private java.lang.String supplies; // 物资
    private java.lang.String specifications; // 规格型号
    private java.lang.String units; // 单位
    private java.lang.Long quantitySupplied; // 供货数量
    private java.math.BigDecimal extaxContractPrice; // 合同单价(除税)(元)
    private java.math.BigDecimal intaxContractPrice; // 合同单价(含税)(元)
    private java.math.BigDecimal extaxSettlementPrice; // 结算单价(除税)(元)
    private java.math.BigDecimal intaxSettlementPrice; // 结算单价(含税)(元)
    private java.math.BigDecimal extaxSummaryAmount; // 结算金额(除税)(元)
    private java.math.BigDecimal intaxSummaryAmount; // 结算金额(含税)(元)
    private java.lang.String remarks; // 备注
    private java.lang.String suppliesCode; //
    private java.lang.String errorMessage; //


    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }

    public Date getSupplyMonth() {
        return supplyMonth;
    }

    public void setSupplyMonth(Date supplyMonth) {
        this.supplyMonth = supplyMonth;
    }

    /**
     * 物资
     */
    public java.lang.String getSupplies() {
        return supplies;
    }

    /**
     * 物资
     */
    public void setSupplies(java.lang.String supplies) {
        this.supplies = supplies;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpecifications() {
        return specifications;
    }

    /**
     * 规格型号
     */
    public void setSpecifications(java.lang.String specifications) {
        this.specifications = specifications;
    }
    /**
     * 单位
     */
    public java.lang.String getUnits() {
        return units;
    }

    /**
     * 单位
     */
    public void setUnits(java.lang.String units) {
        this.units = units;
    }
    /**
     * 供货数量
     */
    public java.lang.Long getQuantitySupplied() {
        return quantitySupplied;
    }

    /**
     * 供货数量
     */
    public void setQuantitySupplied(java.lang.Long quantitySupplied) {
        this.quantitySupplied = quantitySupplied;
    }
    /**
     * 合同单价(除税)(元)
     */
    public java.math.BigDecimal getExtaxContractPrice() {
        return extaxContractPrice;
    }

    /**
     * 合同单价(除税)(元)
     */
    public void setExtaxContractPrice(java.math.BigDecimal extaxContractPrice) {
        this.extaxContractPrice = extaxContractPrice;
    }
    /**
     * 合同单价(含税)(元)
     */
    public java.math.BigDecimal getIntaxContractPrice() {
        return intaxContractPrice;
    }

    /**
     * 合同单价(含税)(元)
     */
    public void setIntaxContractPrice(java.math.BigDecimal intaxContractPrice) {
        this.intaxContractPrice = intaxContractPrice;
    }
    /**
     * 结算单价(除税)(元)
     */
    public java.math.BigDecimal getExtaxSettlementPrice() {
        return extaxSettlementPrice;
    }

    /**
     * 结算单价(除税)(元)
     */
    public void setExtaxSettlementPrice(java.math.BigDecimal extaxSettlementPrice) {
        this.extaxSettlementPrice = extaxSettlementPrice;
    }
    /**
     * 结算单价(含税)(元)
     */
    public java.math.BigDecimal getIntaxSettlementPrice() {
        return intaxSettlementPrice;
    }

    /**
     * 结算单价(含税)(元)
     */
    public void setIntaxSettlementPrice(java.math.BigDecimal intaxSettlementPrice) {
        this.intaxSettlementPrice = intaxSettlementPrice;
    }
    /**
     * 结算金额(除税)(元)
     */
    public java.math.BigDecimal getExtaxSummaryAmount() {
        return extaxSummaryAmount;
    }

    /**
     * 结算金额(除税)(元)
     */
    public void setExtaxSummaryAmount(java.math.BigDecimal extaxSummaryAmount) {
        this.extaxSummaryAmount = extaxSummaryAmount;
    }
    /**
     * 结算金额(含税)(元)
     */
    public java.math.BigDecimal getIntaxSummaryAmount() {
        return intaxSummaryAmount;
    }

    /**
     * 结算金额(含税)(元)
     */
    public void setIntaxSummaryAmount(java.math.BigDecimal intaxSummaryAmount) {
        this.intaxSummaryAmount = intaxSummaryAmount;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     *
     */
    public java.lang.String getSuppliesCode() {
        return suppliesCode;
    }

    /**
     *
     */
    public void setSuppliesCode(java.lang.String suppliesCode) {
        this.suppliesCode = suppliesCode;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }
}
